@@ -19,6 +19,7 @@ from pyextremes.plotting import (
     plot_trace,
     pyextremes_rc,
 )
+from pyextremes.tests import KolmogorovSmirnov
 
 logger = logging.getLogger(__name__)
 
@@ -185,6 +186,14 @@ class EVA:
     def AIC(self) -> float:
         return self.__get_model_attribute("AIC")
 
+    def test_ks(self, significance_level: float = 0.05) -> KolmogorovSmirnov:
+        return KolmogorovSmirnov(
+            extremes=self.extremes,
+            distribution=self.distribution.distribution,
+            fit_parameters=self.model.fit_parameters,
+            significance_level=significance_level,
+        )
+
     def __repr__(self) -> str:
         # Width of repr block
         width = 88
@@ -438,6 +447,7 @@ class EVA:
             if method is BM:
                 block_size : str or pandas.Timedelta, optional
                     Block size (default='365.2425D').
+                    See pandas.to_timedelta for more information.
                 errors : str, optional
                     raise (default) - raise an exception
                         when encountering a block with no data
@@ -453,9 +463,10 @@ class EVA:
             if method is POT:
                 threshold : float
                     Threshold used to find exceedances.
-                r : str or pandas.Timedelta, optional
+                r : pandas.Timedelta or value convertible to timedelta, optional
                     Duration of window used to decluster the exceedances.
                     By default r='24H' (24 hours).
+                    See pandas.to_timedelta for more information.
 
         """
         message = f"for method='{method}' and extremes_type='{extremes_type}'"
@@ -527,7 +538,8 @@ class EVA:
             if method is BM:
                 block_size : str or pandas.Timedelta, optional
                     Block size.
-                    By default is calculated as average distance between `extremes`.
+                    If None (default), then is calculated as median distance
+                    between extreme events.
                 errors : str, optional
                     raise - raise an exception
                         when encountering a block with no data
@@ -544,9 +556,10 @@ class EVA:
                 threshold : float, optional
                     Threshold used to find exceedances.
                     By default is taken as smallest value.
-                r : str or pandas.Timedelta, optional
+                r : pandas.Timedelta or value convertible to timedelta, optional
                     Duration of window used to decluster the exceedances.
                     By default r='24H' (24 hours).
+                    See pandas.to_timedelta for more information.
 
         """
         # Validate `extremes`
@@ -590,7 +603,7 @@ class EVA:
             extremes_kwargs["block_size"] = pd.to_timedelta(
                 kwargs.pop(
                     "block_size",
-                    (extremes.index.max() - extremes.index.min()) / (len(extremes) - 1),
+                    pd.to_timedelta(np.quantile(np.diff(extremes.index), 0.5)),
                 )
             )
             if extremes_kwargs["block_size"] <= pd.to_timedelta("0D"):
@@ -690,6 +703,7 @@ class EVA:
         self,
         figsize: tuple = (8, 5),
         ax: typing.Optional[plt.Axes] = None,
+        show_clusters: bool = False,
     ) -> typing.Tuple[plt.Figure, plt.Axes]:  # pragma: no cover
         """
         Plot extreme events.
@@ -702,6 +716,13 @@ class EVA:
         ax : matplotlib.axes._axes.Axes, optional
             Axes onto which extremes plot is drawn.
             If None (default), a new figure and axes objects are created.
+        show_clusters : bool, optional
+            If True, show cluster boundaries for POT extremes.
+            Has no effect if extremes were extracted using BM method.
+            May produce wrong cluster boundaries if extremes were set using the
+            `set_extremes` or `from_extremes` methods and threshold and inter-cluster
+            distance (r) arguments were not provided.
+            By default is False.
 
         Returns
         -------
@@ -718,6 +739,7 @@ class EVA:
             extremes_type=self.extremes_type,
             block_size=self.extremes_kwargs.get("block_size", None),
             threshold=self.extremes_kwargs.get("threshold", None),
+            r=self.extremes_kwargs.get("r", None) if show_clusters else None,
             figsize=figsize,
             ax=ax,
         )
@@ -1480,8 +1502,7 @@ class EVA:
                 np.full(shape=len(self.extremes), fill_value=0),
                 marker="|",
                 s=40,
-                facecolor="k",
-                edgecolor="None",
+                color="k",
                 lw=0.5,
                 zorder=15,
             )
