@@ -31,6 +31,7 @@ def get_extremes_block_maxima(
         low - get extreme low values
     block_size : str or pandas.Timedelta, optional
         Block size (default='365.2425D').
+        See pandas.to_timedelta for more information.
     errors : str, optional
         raise (default) - raise an exception when encountering a block with no data
         ignore - ignore blocks with no data
@@ -51,18 +52,25 @@ def get_extremes_block_maxima(
     """
     logger.debug(
         "collecting block maxima extreme events using extremes_type=%s, "
-        "block_size=%s, errors=%s" % (extremes_type, block_size, errors)
+        "block_size=%s, errors=%s",
+        extremes_type,
+        block_size,
+        errors,
     )
 
+    if extremes_type not in ["high", "low"]:
+        raise ValueError(
+            f"invalid value in '{extremes_type}' for the 'extremes_type' argument"
+        )
+
+    if errors not in ["raise", "ignore", "coerce"]:
+        raise ValueError(f"invalid value in '{errors}' for the 'errors' argument")
+
     # Get extreme value extraction function
     if extremes_type == "high":
         extremes_func = pd.Series.idxmax
-    elif extremes_type == "low":
-        extremes_func = pd.Series.idxmin
     else:
-        raise ValueError(
-            f"invalid value in '{extremes_type}' for the 'extremes_type' argument"
-        )
+        extremes_func = pd.Series.idxmin
 
     # Parse the 'block_size' argument
     if not isinstance(block_size, pd.Timedelta):
@@ -70,11 +78,12 @@ def get_extremes_block_maxima(
             block_size = pd.to_timedelta(block_size)
         else:
             raise TypeError(
-                f"invalid type in {type(block_size)} for the 'block_size' argument"
+                f"invalid type in {type(block_size).__name__} "
+                f"for the 'block_size' argument"
             )
 
     # Prepare date-time intervals
-    periods = int(np.ceil((ts.index.max() - ts.index.min()) / block_size))
+    periods = int((ts.index.max() - ts.index.min()) / block_size) + 1
     date_time_intervals = pd.interval_range(
         start=ts.index[0],
         freq=block_size,
@@ -94,33 +103,32 @@ def get_extremes_block_maxima(
             empty_intervals += 1
             if errors == "coerce":
                 logger.debug(
-                    "coerced no-data block in [%s ; %s)"
-                    % (interval.left, interval.right)
+                    "coerced no-data block in [%s ; %s)",
+                    interval.left,
+                    interval.right,
                 )
                 extreme_indices.append(interval.mid)
                 extreme_values.append(np.nan)
             elif errors == "ignore":
                 logger.debug(
-                    "ignored no-data block in [%s ; %s)"
-                    % (interval.left, interval.right)
+                    "ignored no-data block in [%s ; %s)",
+                    interval.left,
+                    interval.right,
                 )
-            elif errors == "raise":
+            else:
                 raise ValueError(
                     f"no data in block [{interval.left} ; {interval.right}), "
                     f"fill gaps in the data "
                     f"or set the argument 'errors' to 'coerce' or 'ignore'"
                 )
-            else:
-                raise ValueError(
-                    f"invalid value in '{errors}' for the 'errors' argument"
-                )
 
     # Check last block duration
     if min_last_block is not None:
         ratio = (ts.index.max() - date_time_intervals[-1].left) / block_size
         if ratio < min_last_block:
             logger.debug(
-                "discarded last block with data availability ratio of %s" % ratio
+                "discarded last block with data availability ratio of %s",
+                ratio,
             )
             extreme_indices = extreme_indices[:-1]
             extreme_values = extreme_values[:-1]
@@ -131,9 +139,10 @@ def get_extremes_block_maxima(
             category=NoDataBlockWarning,
         )
 
-    logger.info(
-        "successfully collected %d extreme events, found %s no-data blocks"
-        % (len(extreme_values), empty_intervals)
+    logger.debug(
+        "successfully collected %d extreme events, found %s no-data blocks",
+        len(extreme_values),
+        empty_intervals,
     )
 
     return pd.Series(
