@@ -4,6 +4,7 @@ import pytest
 import scipy.stats
 
 from pyextremes import EVA, get_model
+from pyextremes.tests import KolmogorovSmirnov
 
 
 @pytest.fixture(scope="function")
@@ -90,13 +91,16 @@ class TestEVA:
             )
             assert np.allclose(eva_model.data.values, [1, 2, 3])
 
-        with pytest.raises(TypeError, match=r"invalid dtype.*`data` argument.*numeric"):
-            EVA(
-                data=pd.Series(
-                    data=["a", "b", "c"],
-                    index=pd.DatetimeIndex(["2020", "2021", "2022"]),
+        with pytest.warns(RuntimeWarning, match=r"`data`.*not numeric.*converting"):
+            with pytest.raises(
+                TypeError, match=r"invalid dtype.*`data` argument.*numeric"
+            ):
+                EVA(
+                    data=pd.Series(
+                        data=["a", "b", "c"],
+                        index=pd.DatetimeIndex(["2020", "2021", "2022"]),
+                    )
                 )
-            )
 
         with pytest.raises(TypeError, match=r"index of `data`.*date-time.*not"):
             EVA(data=pd.Series(data=[1, 2, 3], index=["2020", "2021", "2022"]))
@@ -339,7 +343,7 @@ class TestEVA:
         assert eva_model.extremes_kwargs["errors"] == "ignore"
         assert eva_model.extremes_kwargs["min_last_block"] is None
         expected_block_size = (
-            ((index.max() - index.min()) / (len(index) - 1)).to_numpy().astype(float)
+            pd.to_timedelta(np.quantile(np.diff(index), 0.5)).to_numpy().astype(float),
         )
         actual_block_size = (
             eva_model.extremes_kwargs["block_size"].to_numpy().astype(float)
@@ -563,3 +567,15 @@ class TestEVA:
         )
         assert isinstance(rv_summary, pd.DataFrame)
         assert len(rv_summary) == 2
+
+    @pytest.mark.parametrize("extremes_method", ["BM", "POT"])
+    def test_test_ks(self, eva_model_bm_mle, eva_model_pot_mle, extremes_method):
+        eva_model = {
+            "BM": eva_model_bm_mle,
+            "POT": eva_model_pot_mle,
+        }[extremes_method]
+        assert isinstance(eva_model.test_ks(), KolmogorovSmirnov)
+        if extremes_method == "BM":
+            assert eva_model.test_ks().success
+        else:
+            assert not eva_model.test_ks().success
